# Up to an age of t_1 = 30, a forest stand of interest has a survival
# probability of 0.95. Up to an age of t_2 = 80, it has a survival
# probability of 0.83. If we assume an exponential decay process for the
# 50-year period, what is the exponential decay rate r?
r <- exp_decay_rate(30, 80, 0.95, 0.83)
print(r)
# Check it
0.95 * exp(-r * (80 - 30)) # 0.83
Run the code above in your browser using DataLab