Learn R Programming

care4cmodel (version 1.0.3)

fuel_cons_forwarder_1: Fuel Consumption of a Forwarder per Cubic Meter Harvested Wood (Version #1)

Description

Fuel consumption per m³ harvested wood derived from the data provided by grigolato_et_al_2022;textualcare4cmodel. Includes loading, transportation, and unloading.

Usage

fuel_cons_forwarder_1(aed)

Value

Fuel consumption of a forwarder in liters diesel fuel per m³ wood to be handled

Arguments

aed

Average extraction distance to the nearest truck road

References

grigolato_et_al_2022care4cmodel

Examples

Run this code
  frd <- c(15, 30, 60, 100) # Forest road densities m/ha
  avg_extraction_distance(frd) |>
    fuel_cons_forwarder_1()

Run the code above in your browser using DataLab