Learn R Programming

care4cmodel (version 1.0.3)

fuel_cons_forwarder_2: Fuel Consumption of a Forwarder per Cubic Meter Harvested Wood (Version #2)

Description

Fuel consumption per m³ harvested wood after karha_et_al_2023;textualcare4cmodel. Includes loading, transportation, and unloading.

Usage

fuel_cons_forwarder_2(aed, harvest_vol_ha, mineral_soil = TRUE)

Value

Fuel consumption of a forwarder in liters diesel fuel per m³ wood to be handled

Arguments

aed

Average extraction distance to the nearest truck road

harvest_vol_ha

Harvested merchandable wood volume over bark per ha (m³/ha)

mineral_soil

Logical, TRUE (default) if the operation takes place on mineral soil, FALSE if not

References

karha_et_al_2023care4cmodel

Examples

Run this code
  frd <- c(15, 30, 60, 100) # Forest road densities m/ha
  aed <- avg_extraction_distance(frd)

  fuel_cons_forwarder_2(aed, 100, TRUE)
  fuel_cons_forwarder_2(aed, 100, FALSE)

Run the code above in your browser using DataLab