Learn R Programming

care4cmodel (version 1.0.3)

fuel_cons_harvester_1: Fuel Consumption of a Harvester per Cubic Meter Harvested Wood (Version #1)

Description

Fuel consumption depends on the average tree volume. For tree diameters at breast height < 15 cm the function gives back NA, because the assumed machine does not work with such small trees. Estimated after Bacescu_et_al_2022;textualcare4cmodel.

Usage

fuel_cons_harvester_1(tree_vol, tree_dbh)

Value

Fuel consumption of a harvester in liters diesel fuel per m³ harvested wood

Arguments

tree_vol

Average standing merchandable wood volume over bark (m³) per harvested tree

tree_dbh

Average diameter at breast height (cm) per harvested tree

References

Bacescu_et_al_2022care4cmodel

Examples

Run this code
  dbh <- seq(10, 70, 10) # Vector of tree dbh in cm
  vol <- dbh ^ 2 / 1000  # Simple Volume estimate (m³) with Denzin's formula

  fuel_cons_harvester_1(vol, dbh)

Run the code above in your browser using DataLab