Learn R Programming

care4cmodel (version 1.0.3)

fuel_cons_harvester_2: Fuel Consumption of a Harvester per Cubic Meter Harvested Wood (Version #2)

Description

Fuel consumption of a harvester in liters diesel per m³ havested wood after karha_et_al_2023;textualcare4cmodel.

Usage

fuel_cons_harvester_2(tree_vol, harvest_vol_ha, thinning = TRUE)

Value

Fuel consumption of a harvester in liters diesel fuel per m³ harvested wood

Arguments

tree_vol

Average standing merchandable wood volume over bark (m³) per harvested tree

harvest_vol_ha

Harvested merchandable wood volume over bark per ha (m³/ha)

thinning

Logical, TRUE (default) if the harvest is a thinning, or another kind of felling operation (FALSE)

References

karha_et_al_2023care4cmodel

Examples

Run this code
  tree_vol    <- c(0.03,  0.10,  1.00,  2.00,  5.00)
  harvest_vol <- c(5.00, 10.00, 50.00, 25.00, 10.00)

  fuel_cons_harvester_2(tree_vol, harvest_vol, TRUE)
  fuel_cons_harvester_2(tree_vol, harvest_vol, FALSE)

Run the code above in your browser using DataLab