Learn R Programming

care4cmodel (version 1.0.3)

new_c4c_base_result: Constructor for the Class c4c_base_result

Description

For internal use only. Objects of class c4c_base_result are only constructed by functions that evaluate simulation runs. There is no validator function, for such objects, because their consistency is guaranteed by the functions that build them.

Usage

new_c4c_base_result(x = list())

Value

x, but with the class attribute c4c_base_result

Arguments

x

An object to become a c4c_base_result