Learn R Programming

care4cmodel (version 1.0.3)

pine_no_thinning_and_clearcut_1: pine_no_thinning_and_clearcut_1

Description

Generated from simulation runs to mimic a concept of treating a Scots pine stand with no thinnings and a short final harvest phase with the model SILVA.

Usage

pine_no_thinning_and_clearcut_1

Arguments

Format

An object of class c4c_concept of length 3.