Learn R Programming

care4cmodel (version 1.0.3)

pine_thinning_from_above_1: pine_thinning_from_above_1

Description

Generated from simulation runs to mimic a concept similar to the Scots pine management of the Bavarian State Forest with the model SILVA.

Usage

pine_thinning_from_above_1

Arguments

Format

An object of class c4c_concept of length 3.