powered by
Fuel consumption per m³ harvested wood after karha_et_al_2023;textualcare4cmodel. Includes loading, transportation, and unloading.
fuel_cons_forwarder_2(aed, harvest_vol_ha, mineral_soil = TRUE)
Fuel consumption of a forwarder in liters diesel fuel per m³ wood to be handled
Average extraction distance to the nearest truck road
Harvested merchandable wood volume over bark per ha (m³/ha)
Logical, TRUE (default) if the operation takes place on mineral soil, FALSE if not
karha_et_al_2023care4cmodel
frd <- c(15, 30, 60, 100) # Forest road densities m/ha aed <- avg_extraction_distance(frd) fuel_cons_forwarder_2(aed, 100, TRUE) fuel_cons_forwarder_2(aed, 100, FALSE)
Run the code above in your browser using DataLab